@@ -18,11 +18,10 @@ server <- function(input, output,session) {
   p1=iris%>%ggplot(aes(x=Sepal.Length,y=Sepal.Width,colour=Species))+geom_point()
   p2=iris%>%ggplot(aes(x=Sepal.Length,y=Sepal.Width,colour=Species))+geom_line()+geom_point()
   p3=list(p1=p1,p2=p2)
-  p4=iris%>%ggplot(aes(x=Sepal.Length,y=Sepal.Width,colour=Petal.Length))+geom_point()
+
   output$p<-renderPlot({p1})
   outp1<-callModule(ggEdit,'pOut1',obj=reactive(list(p1=p1)))
-  outp2<-callModule(ggEdit,'pOut2',obj=reactive(p3))
-  outp3<-callModule(ggEdit,'pOut3',obj=reactive(p4))
+  outp2<-callModule(ggEdit,'pOut2',obj=reactive(p3),showDefaults=T,height=300)
 
   output$x1<-renderUI({
     layerTxt=outp1()$UpdatedLayerCalls$p1[[1]]
